@@ -2,7 +2,9 @@ package cli
 
 import (
 	"fmt"
+	"os"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/cache"
 	"github.com/jandedobbeleer/oh-my-posh/src/cli/image"
 	"github.com/jandedobbeleer/oh-my-posh/src/config"
 	"github.com/jandedobbeleer/oh-my-posh/src/prompt"
@@ -48,10 +50,19 @@ Exports the config to an image file ~/mytheme.png.
 Exports the config to an image file using customized output settings.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
-		cfg, _ := config.Load(configFlag, shell.GENERIC, false)
+		cache.Init(os.Getenv("POSH_SHELL"))
+
+		err := setConfigFlag()
+		if err != nil {
+			exitcode = 666
+			fmt.Println(err.Error())
+			return
+		}
+
+		cfg := config.Load(configFlag, false)
 
 		flags := &runtime.Flags{
-			Config:        cfg.Source,
+			ConfigPath:    cfg.Source,
 			Shell:         shell.GENERIC,
 			TerminalWidth: 120,
 		}
@@ -63,7 +74,7 @@ Exports the config to an image file using customized output settings.`,
 
 		defer func() {
 			template.SaveCache()
-			env.Close()
+			cache.Close()
 		}()
 
 		// set sane defaults for things we don't print
@@ -132,3 +143,17 @@ func init() {
 
 	exportCmd.AddCommand(imageCmd)
 }
+
+func setConfigFlag() error {
+	if configFlag != "" {
+		return nil
+	}
+
+	configPath, OK := cache.Get[string](cache.Session, config.SourceKey)
+	if !OK {
+		return fmt.Errorf("no config found in session cache, please provide a config using the --config flag")
+	}
+
+	configFlag = configPath
+	return nil
+}
