@@ -6,7 +6,6 @@ import (
 
 	"github.com/alecthomas/assert"
 	"github.com/jandedobbeleer/oh-my-posh/src/cache"
-	cache_ "github.com/jandedobbeleer/oh-my-posh/src/cache/mock"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/mock"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
@@ -43,9 +42,8 @@ func TestGetAnsiFromColorString(t *testing.T) {
 func TestMakeColors(t *testing.T) {
 	env := &mock.Environment{}
 
-	c := &cache_.Cache{}
-	c.On("Get", "accent_color").Return("", true)
-	env.On("Session").Return(c)
+	cache.Set(cache.Device, "accent_color", Set{}, cache.INFINITE)
+	defer cache.DeleteAll(cache.Device)
 
 	env.On("WindowsRegistryKeyValue", `HKEY_CURRENT_USER\Software\Microsoft\Windows\DWM\ColorizationColor`).Return(&runtime.WindowsRegistryValue{}, errors.New("err"))
 	colors := MakeColors(nil, false, "", env)
