@@ -38,7 +38,7 @@ type Configuration struct {
 
 func (s *Resource) Add(configPath string) {
 	if configPath == "" || strings.HasPrefix(configPath, "http") {
-		log.Debug("Invalid configuration path:", configPath)
+		log.Debug("local configuration not provided or remote configuration, skipping")
 		return
 	}
 
